@@ -1,25 +1,12 @@
-/*
-MIT License
+/*[License]
+    - Author: Molese <molese@protonmail.com> 2022
 
-Copyright (c) 2022 Molese
+    Licensed under either of
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+    * Apache License, Version 2.0 (LICENSE-APACHE or https://www.apache.org/licenses/LICENSE-2.0)
+    * MIT license (LICENSE-MIT or https://opensource.org/licenses/MIT)
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
+    at your option.
 */
 
 #![allow(missing_debug_implementations)]
@@ -34,7 +21,7 @@ SOFTWARE.
 
 //! MoCkInG SpOnGeBoB SqUaRePaNtS TeXt gEnErAtOr.
 
-use fastrand::bool;
+use fastrand::bool as fastbool;
 use std::{env, error::Error, fs::File, io::Read};
 
 /// The necessary configurations for initializing spongmock.
@@ -85,7 +72,12 @@ impl Config {
 
 /// Returns a random boolean value.
 pub fn rand_bool() -> bool {
-    bool()
+    fastbool()
+}
+
+/// Returns true if n is even and false if n is odd.
+pub fn is_even(n: u128) -> bool {
+    n % 2 == 0
 }
 
 fn mock_refstr(s: &str, randomize: bool) -> String {
@@ -98,7 +90,7 @@ fn mock_refstr(s: &str, randomize: bool) -> String {
             } else {
                 res.push(c.to_ascii_lowercase());
             }
-        } else if i % 2 == 0 {
+        } else if is_even(i.try_into().unwrap()) {
             res.push(c.to_ascii_uppercase());
         } else {
             res.push(c.to_ascii_lowercase());
@@ -175,4 +167,14 @@ mod tests {
     fn test_mock_random() {
         assert_ne!(mock_any("ABCDEFG", true), "AbCdEfG");
     }
+
+    #[test]
+    fn test_is_even_even() {
+        assert_eq!(is_even(2), true);
+    }
+
+    #[test]
+    fn test_is_even_odd() {
+        assert_eq!(is_even(3), false);
+    }
 }
